@@ -33,10 +33,10 @@ import (
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/apimachinery/pkg/util/uuid"
 	"k8s.io/apimachinery/pkg/util/wait"
+	quotav1 "k8s.io/apiserver/pkg/quota/v1"
 	"k8s.io/client-go/kubernetes"
 	batchv1client "k8s.io/client-go/kubernetes/typed/batch/v1"
 	corev1client "k8s.io/client-go/kubernetes/typed/core/v1"
-	quotav1 "k8s.io/kubernetes/pkg/quota/v1"
 	e2e "k8s.io/kubernetes/test/e2e/framework"
 	e2epod "k8s.io/kubernetes/test/e2e/framework/pod"
 	"k8s.io/kubernetes/test/e2e/framework/statefulset"
@@ -55,6 +55,7 @@ import (
 	"github.com/openshift/library-go/pkg/image/imageutil"
 	"github.com/openshift/origin/test/extended/testdata"
 	"github.com/openshift/origin/test/extended/util/ibmcloud"
+	utilimage "github.com/openshift/origin/test/extended/util/image"
 )
 
 // WaitForInternalRegistryHostname waits for the internal registry hostname to be made available to the cluster.
@@ -772,9 +773,9 @@ func (t *BuildResult) Logs() (string, error) {
 		return t.LogDumper(t.Oc, t)
 	}
 
-	buildOuput, err := t.Oc.Run("logs").Args("-f", t.BuildPath, "--timestamps").Output()
+	buildOuput, buildErr, err := t.Oc.Run("logs").Args("-f", t.BuildPath, "--timestamps", "--v", "10").Outputs()
 	if err != nil {
-		return "", fmt.Errorf("Error retrieving logs for %#v: %v", *t, err)
+		return "", fmt.Errorf("Error retrieving logs for build %q: (%s) %v", t.BuildName, buildErr, err)
 	}
 
 	return buildOuput, nil
@@ -790,9 +791,9 @@ func (t *BuildResult) LogsNoTimestamp() (string, error) {
 		return t.LogDumper(t.Oc, t)
 	}
 
-	buildOuput, err := t.Oc.Run("logs").Args("-f", t.BuildPath).Output()
+	buildOuput, buildErr, err := t.Oc.Run("logs").Args("-f", t.BuildPath).Outputs()
 	if err != nil {
-		return "", fmt.Errorf("Error retrieving logs for %#v: %v", *t, err)
+		return "", fmt.Errorf("Error retrieving logs for build %q: (%s) %v", t.BuildName, buildErr, err)
 	}
 
 	return buildOuput, nil
@@ -995,9 +996,35 @@ func WaitForServiceAccount(c corev1client.ServiceAccountInterface, name string)
 	return wait.Poll(100*time.Millisecond, 3*time.Minute, waitFn)
 }
 
-// WaitForNamespaceSCCAnnotations waits up to 2 minutes for the cluster-policy-controller to add the SCC related
+// WaitForNamespaceSCCAnnotations waits up to 30s for the cluster-policy-controller to add the SCC related
 // annotations to the provided namespace.
-func WaitForNamespaceSCCAnnotations(c projectv1typedclient.ProjectV1Interface, name string) error {
+func WaitForNamespaceSCCAnnotations(c corev1client.CoreV1Interface, name string) error {
+	waitFn := func() (bool, error) {
+		ns, err := c.Namespaces().Get(context.Background(), name, metav1.GetOptions{})
+		if err != nil {
+			// it is assumed the project was created prior to calling this, so we
+			// do not distinguish not found errors
+			return false, err
+		}
+		if ns.Annotations == nil {
+			return false, nil
+		}
+		for k := range ns.Annotations {
+			// annotations to check based off of
+			// https://github.com/openshift/cluster-policy-controller/blob/master/pkg/security/controller/namespace_scc_allocation_controller.go#L112
+			if k == securityv1.UIDRangeAnnotation {
+				return true, nil
+			}
+		}
+		e2e.Logf("namespace %s current annotation set: %#v", name, ns.Annotations)
+		return false, nil
+	}
+	return wait.Poll(time.Duration(250*time.Millisecond), 30*time.Minute, waitFn)
+}
+
+// WaitForProjectSCCAnnotations waits up to 30s for the cluster-policy-controller to add the SCC related
+// annotations to the provided namespace.
+func WaitForProjectSCCAnnotations(c projectv1typedclient.ProjectV1Interface, name string) error {
 	waitFn := func() (bool, error) {
 		proj, err := c.Projects().Get(context.Background(), name, metav1.GetOptions{})
 		if err != nil {
@@ -1018,7 +1045,7 @@ func WaitForNamespaceSCCAnnotations(c projectv1typedclient.ProjectV1Interface, n
 		e2e.Logf("project %s current annotation set: %#v", name, proj.Annotations)
 		return false, nil
 	}
-	return wait.Poll(time.Duration(15*time.Second), 2*time.Minute, waitFn)
+	return wait.Poll(time.Duration(500*time.Millisecond), 30*time.Minute, waitFn)
 }
 
 // WaitForAnImageStream waits for an ImageStream to fulfill the isOK function
@@ -1069,12 +1096,7 @@ func WaitForAnImageStream(client imagev1typedclient.ImageStreamInterface,
 // WaitForAnImageStreamTag waits until an image stream with given name has non-empty history for given tag.
 // Defaults to waiting for 300 seconds
 func WaitForAnImageStreamTag(oc *CLI, namespace, name, tag string) error {
-	return TimedWaitForAnImageStreamTag(oc, namespace, name, tag, time.Second*300)
-}
-
-// TimedWaitForAnImageStreamTag waits until an image stream with given name has non-empty history for given tag.
-// Gives up waiting after the specified waitTimeout
-func TimedWaitForAnImageStreamTag(oc *CLI, namespace, name, tag string, waitTimeout time.Duration) error {
+	waitTimeout := time.Second * 300
 	g.By(fmt.Sprintf("waiting for an is importer to import a tag %s into a stream %s", tag, name))
 	start := time.Now()
 	c := make(chan error)
@@ -1409,18 +1431,7 @@ func FixturePath(elem ...string) string {
 
 	if testsStarted {
 		// extract the contents to disk
-		if err := testdata.RestoreAssets(fixtureDir, relativePath); err != nil {
-			panic(err)
-		}
-		if err := filepath.Walk(fullPath, func(path string, info os.FileInfo, err error) error {
-			if err := os.Chmod(path, 0640); err != nil {
-				return err
-			}
-			if stat, err := os.Lstat(path); err == nil && stat.IsDir() {
-				return os.Chmod(path, 0755)
-			}
-			return nil
-		}); err != nil {
+		if err := restoreFixtureAssets(fixtureDir, relativePath); err != nil {
 			panic(err)
 		}
 
@@ -1434,21 +1445,71 @@ func FixturePath(elem ...string) string {
 	return absPath
 }
 
+// restoreFixtureAsset restores an asset under the given directory and post-processes
+// any changes required by the test. It hardcodes file modes to 0640 and ensures image
+// values are replaced.
+func restoreFixtureAsset(dir, name string) error {
+	data, err := testdata.Asset(name)
+	if err != nil {
+		return err
+	}
+	data, err = utilimage.ReplaceContents(data)
+	if err != nil {
+		return err
+	}
+	info, err := testdata.AssetInfo(name)
+	if err != nil {
+		return err
+	}
+	err = os.MkdirAll(assetFilePath(dir, filepath.Dir(name)), os.FileMode(0755))
+	if err != nil {
+		return err
+	}
+	err = ioutil.WriteFile(assetFilePath(dir, name), data, 0640)
+	if err != nil {
+		return err
+	}
+	err = os.Chtimes(assetFilePath(dir, name), info.ModTime(), info.ModTime())
+	if err != nil {
+		return err
+	}
+	return nil
+}
+
+// restoreFixtureAssets restores an asset under the given directory recursively, changing
+// any necessary content. This duplicates a method in testdata but with the additional
+// requirements for setting disk permissions and for altering image content.
+func restoreFixtureAssets(dir, name string) error {
+	children, err := testdata.AssetDir(name)
+	// File
+	if err != nil {
+		return restoreFixtureAsset(dir, name)
+	}
+	// Dir
+	for _, child := range children {
+		err = restoreFixtureAssets(dir, filepath.Join(name, child))
+		if err != nil {
+			return err
+		}
+	}
+	return nil
+}
+
+func assetFilePath(dir, name string) string {
+	cannonicalName := strings.Replace(name, "\\", "/", -1)
+	return filepath.Join(append([]string{dir}, strings.Split(cannonicalName, "/")...)...)
+}
+
 // FetchURL grabs the output from the specified url and returns it.
 // It will retry once per second for duration retryTimeout if an error occurs during the request.
 func FetchURL(oc *CLI, url string, retryTimeout time.Duration) (string, error) {
-
 	ns := oc.KubeFramework().Namespace.Name
-	execPodName := CreateExecPodOrFail(oc.AdminKubeClient().CoreV1(), ns, string(uuid.NewUUID()))
+	execPod := CreateExecPodOrFail(oc.AdminKubeClient(), ns, string(uuid.NewUUID()))
 	defer func() {
-		oc.AdminKubeClient().CoreV1().Pods(ns).Delete(context.Background(), execPodName, *metav1.NewDeleteOptions(1))
+		oc.AdminKubeClient().CoreV1().Pods(ns).Delete(context.Background(), execPod.Name, *metav1.NewDeleteOptions(1))
 	}()
 
-	execPod, err := oc.AdminKubeClient().CoreV1().Pods(ns).Get(context.Background(), execPodName, metav1.GetOptions{})
-	if err != nil {
-		return "", err
-	}
-
+	var err error
 	var response string
 	waitFn := func() (bool, error) {
 		e2e.Logf("Waiting up to %v to wget %s", retryTimeout, url)
@@ -1553,26 +1614,6 @@ func GetEndpointAddress(oc *CLI, name string) (string, error) {
 	return fmt.Sprintf("%s:%d", endpoint.Subsets[0].Addresses[0].IP, endpoint.Subsets[0].Ports[0].Port), nil
 }
 
-// CreateExecPodOrFail creates a simple busybox pod in a sleep loop used as a
-// vessel for kubectl exec commands.
-// Returns the name of the created pod.
-// TODO: expose upstream
-func CreateExecPodOrFail(client corev1client.CoreV1Interface, ns, name string) string {
-	e2e.Logf("Creating new exec pod")
-	execPod := e2epod.NewExecPodSpec(ns, name, false)
-	created, err := client.Pods(ns).Create(context.Background(), execPod, metav1.CreateOptions{})
-	o.Expect(err).NotTo(o.HaveOccurred())
-	err = wait.PollImmediate(e2e.Poll, 5*time.Minute, func() (bool, error) {
-		retrievedPod, err := client.Pods(execPod.Namespace).Get(context.Background(), created.Name, metav1.GetOptions{})
-		if err != nil {
-			return false, nil
-		}
-		return retrievedPod.Status.Phase == corev1.PodRunning, nil
-	})
-	o.Expect(err).NotTo(o.HaveOccurred())
-	return created.Name
-}
-
 // CheckForBuildEvent will poll a build for up to 1 minute looking for an event with
 // the specified reason and message template.
 func CheckForBuildEvent(client corev1client.CoreV1Interface, build *buildv1.Build, reason, message string) {
@@ -1858,37 +1899,6 @@ func GetRouterPodTemplate(oc *CLI) (*corev1.PodTemplateSpec, string, error) {
 	return nil, "", kapierrs.NewNotFound(schema.GroupResource{Group: "apps.openshift.io", Resource: "deploymentconfigs"}, "router")
 }
 
-// FindImageFormatString returns a format string for components on the cluster. It returns false
-// if no format string could be inferred from the cluster. OpenShift 4.0 clusters will not be able
-// to infer an image format string, so you must wrap this method in one that can locate your specific
-// image.
-func FindImageFormatString(oc *CLI) (string, bool) {
-	// legacy support for 3.x clusters
-	template, _, err := GetRouterPodTemplate(oc)
-	if err == nil {
-		if strings.Contains(template.Spec.Containers[0].Image, "haproxy-router") {
-			return strings.Replace(template.Spec.Containers[0].Image, "haproxy-router", "${component}", -1), true
-		}
-	}
-	// in openshift 4.0, no image format can be calculated on cluster
-	return "openshift/origin-${component}:latest", false
-}
-
-func FindCLIImage(oc *CLI) (string, bool) {
-	// look up image stream
-	is, err := oc.AdminImageClient().ImageV1().ImageStreams("openshift").Get(context.Background(), "cli", metav1.GetOptions{})
-	if err == nil {
-		for _, tag := range is.Spec.Tags {
-			if tag.Name == "latest" && tag.From != nil && tag.From.Kind == "DockerImage" {
-				return tag.From.Name, true
-			}
-		}
-	}
-
-	format, ok := FindImageFormatString(oc)
-	return strings.Replace(format, "${component}", "cli", -1), ok
-}
-
 func FindRouterImage(oc *CLI) (string, error) {
 	configclient := oc.AdminConfigClient().ConfigV1()
 	o, err := configclient.ClusterOperators().Get(context.Background(), "ingress", metav1.GetOptions{})
